mailr15077 - /branches/frame_order_testing/specific_fns/frame_order.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on December 12, 2011 - 11:56:
Author: bugman
Date: Mon Dec 12 11:56:43 2011
New Revision: 15077

URL: http://svn.gna.org/viewcvs/relax?rev=15077&view=rev
Log:
Fix for the frame order base loop - only spins for the moving domain are now 
looped over.


Modified:
    branches/frame_order_testing/specific_fns/frame_order.py

Modified: branches/frame_order_testing/specific_fns/frame_order.py
URL: 
http://svn.gna.org/viewcvs/relax/branches/frame_order_testing/specific_fns/frame_order.py?rev=15077&r1=15076&r2=15077&view=diff
==============================================================================
--- branches/frame_order_testing/specific_fns/frame_order.py (original)
+++ branches/frame_order_testing/specific_fns/frame_order.py Mon Dec 12 
11:56:43 2011
@@ -1390,8 +1390,9 @@
         # First the tensors.
         yield 'A'
 
-        # Then the spin IDs.
-        for spin, spin_id in spin_loop(return_id=True):
+        # Then the spin IDs for the moving domain.
+        id = cdp.domain[self._domain_moving()]
+        for spin, spin_id in spin_loop(id, return_id=True):
             # Re-initialise the data structure.
             base_ids = [spin_id, None, None]
 




Related Messages


Powered by MHonArc, Updated Mon Dec 12 12:20:02 2011